@@ -1,11 +1,14 @@
-.onLoad <- function(libname, pkgname){
+.onLoad <- function(libname, pkgname) {
   #' setting options for nthreads when package is loaded
   #' @param libname library name
   #' @param pkgname package name
-  #' @return Changes number of threads used. 
-  
+  #' @return Changes number of threads used.
+
   # adds info on number of threads to options()
+  # setBoottest_nthreads()
+
   setBoottest_nthreads()
-  
+  setBoottest_boot_algo()
+
   invisible()
 }
